@@ -25,7 +25,6 @@ describe 'ironic::conductor' do
   let :default_params do
     { :package_ensure                => 'present',
       :enabled                       => true,
-      :enabled_hardware_types        => ['ipmi'],
       :force_power_state_during_sync => true }
   end
 
@@ -61,7 +60,7 @@ describe 'ironic::conductor' do
     end
 
     it 'configures ironic.conf' do
-      is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi')
+      is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
       is_expected.to contain_ironic_config('conductor/automated_clean').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/cleaning_network').with(:value => '<SERVICE DEFAULT>')
@@ -80,6 +79,7 @@ describe 'ironic::conductor' do
       is_expected.to contain_ironic_config('neutron/port_setup_delay').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/sync_power_state_interval').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/sync_power_state_workers').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_state_sync_max_retries').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_failure_recovery_interval').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/conductor_group').with(:value => '<SERVICE DEFAULT>')
@@ -108,6 +108,7 @@ describe 'ironic::conductor' do
           :port_setup_delay                  => '15',
           :power_state_change_timeout        => '300',
           :sync_power_state_interval         => 120,
+          :sync_power_state_workers          => 2,
           :power_state_sync_max_retries      => 5,
           :power_failure_recovery_interval   => 120,
           :conductor_group                   => 'in-the-closet-to-the-left',
@@ -140,6 +141,7 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('neutron/port_setup_delay').with_value(p[:port_setup_delay])
         is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with_value(p[:power_state_change_timeout])
         is_expected.to contain_ironic_config('conductor/sync_power_state_interval').with_value(p[:sync_power_state_interval])
+        is_expected.to contain_ironic_config('conductor/sync_power_state_workers').with_value(p[:sync_power_state_workers])
         is_expected.to contain_ironic_config('conductor/power_state_sync_max_retries').with_value(p[:power_state_sync_max_retries])
         is_expected.to contain_ironic_config('conductor/power_failure_recovery_interval').with_value(p[:power_failure_recovery_interval])
         is_expected.to contain_ironic_config('conductor/conductor_group').with_value(p[:conductor_group])
@@ -185,14 +187,6 @@ describe 'ironic::conductor' do
             { :conductor_package => 'ironic-conductor',
               :conductor_service => 'ironic-conductor' }
           end
-          # https://bugs.launchpad.net/cloud-archive/+bug/1572800
-          it 'installs ipmitool package' do
-            is_expected.to contain_package('ipmitool').with(
-              :ensure => 'present',
-              :name   => 'ipmitool',
-              :tag    => ['openstack', 'ironic-package'],
-            )
-          end
         when 'RedHat'
           let :platform_params do
             { :conductor_service => 'ironic-conductor' }
