@@ -12,6 +12,7 @@ describe 'ironic::db' do
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
       )}
@@ -25,6 +26,7 @@ describe 'ironic::db' do
           :database_max_pool_size           => '21',
           :database_max_retries             => '11',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
           :database_max_overflow            => '21',
           :database_retry_interval          => '11',
           :database_db_max_retries          => '-1',
@@ -42,6 +44,7 @@ describe 'ironic::db' do
         :retry_interval          => '11',
         :max_overflow            => '21',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
       )}
     end
   end
