@@ -4,6 +4,8 @@ describe 'ironic::db::sync' do
 
   shared_examples_for 'ironic-dbsync' do
 
+    it { is_expected.to contain_class('ironic::deps') }
+
     it 'runs ironic-manage db_sync' do
       is_expected.to contain_exec('ironic-dbsync').with(
         :command     => 'ironic-dbsync --config-file /etc/ironic/ironic.conf ',
@@ -12,6 +14,7 @@ describe 'ironic::db::sync' do
         :refreshonly => 'true',
         :try_sleep   => 5,
         :tries       => 10,
+        :timeout     => 300,
         :logoutput   => 'on_failure',
         :subscribe   => ['Anchor[ironic::install::end]',
                          'Anchor[ironic::config::end]',
@@ -27,10 +30,11 @@ describe 'ironic::db::sync' do
       )
     end
 
-    describe "overriding extra_params" do
+    describe "overriding params" do
         let :params do
             {
-                :extra_params => '--config-file /etc/ironic/ironic_01.conf',
+                :extra_params    => '--config-file /etc/ironic/ironic_01.conf',
+                :db_sync_timeout => 750,
             }
         end
         it { is_expected.to contain_exec('ironic-dbsync').with(
@@ -40,6 +44,7 @@ describe 'ironic::db::sync' do
             :refreshonly => true,
             :try_sleep   => 5,
             :tries       => 10,
+            :timeout     => 750,
             :logoutput   => 'on_failure',
             :subscribe   => ['Anchor[ironic::install::end]',
                              'Anchor[ironic::config::end]',
