@@ -23,10 +23,7 @@ require 'spec_helper'
 describe 'ironic::drivers::pxe' do
 
   let :default_params do
-    { :pxe_bootfile_name        => 'pxelinux.0',
-      :pxe_config_template      => '$pybasedir/drivers/modules/pxe_config.template',
-      :tftp_root                => '/tftpboot',
-      :tftp_master_path         => '/tftpboot/master_images',
+    { :uefi_ipxe_bootfile_name        => 'snponly.efi',
     }
   end
 
@@ -40,39 +37,20 @@ describe 'ironic::drivers::pxe' do
     end
 
     it 'configures ironic.conf' do
-      is_expected.to contain_ironic_config('pxe/pxe_append_params').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('pxe/pxe_bootfile_name').with_value(p[:pxe_bootfile_name])
-      is_expected.to contain_ironic_config('pxe/pxe_config_template').with_value(p[:pxe_config_template])
+      is_expected.to contain_ironic_config('pxe/kernel_append_params').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('pxe/pxe_bootfile_name').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('pxe/pxe_config_template').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('pxe/ipxe_bootfile_name').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('pxe/ipxe_config_template').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('pxe/tftp_server').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('pxe/tftp_root').with_value(p[:tftp_root])
+      is_expected.to contain_ironic_config('pxe/tftp_root').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('pxe/images_path').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('pxe/tftp_master_path').with_value(p[:tftp_master_path])
+      is_expected.to contain_ironic_config('pxe/tftp_master_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('pxe/instance_master_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('pxe/uefi_pxe_bootfile_name').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('pxe/uefi_pxe_config_template').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('pxe/ipxe_enabled').with_value(false)
-    end
-
-    context 'when overriding only ipxe_enabled' do
-      before do
-        params.merge!(
-          :ipxe_enabled             => true,
-        )
-      end
-
-      it 'detects correct boot parameters' do
-        is_expected.to contain_ironic_config('pxe/pxe_append_params').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/pxe_bootfile_name').with_value('undionly.kpxe')
-        is_expected.to contain_ironic_config('pxe/pxe_config_template').with_value('$pybasedir/drivers/modules/ipxe_config.template')
-        is_expected.to contain_ironic_config('pxe/tftp_server').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/tftp_root').with_value(p[:tftp_root])
-        is_expected.to contain_ironic_config('pxe/images_path').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/tftp_master_path').with_value(p[:tftp_master_path])
-        is_expected.to contain_ironic_config('pxe/instance_master_path').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/uefi_pxe_bootfile_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/uefi_pxe_config_template').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_config('pxe/ipxe_enabled').with_value(true)
-      end
+      is_expected.to contain_ironic_config('pxe/uefi_ipxe_bootfile_name').with_value('snponly.efi')
+      is_expected.to contain_ironic_config('pxe/ipxe_enabled').with_ensure('absent')
     end
 
     context 'when overriding only enable_ppc64le' do
@@ -91,7 +69,7 @@ describe 'ironic::drivers::pxe' do
     context 'when overriding parameters' do
       before do
         params.merge!(
-          :pxe_append_params         => 'foo',
+          :kernel_append_params      => 'foo',
           :pxe_config_template       => 'bar',
           :tftp_server               => '192.168.0.1',
           :tftp_root                 => '/mnt/ftp',
@@ -99,9 +77,9 @@ describe 'ironic::drivers::pxe' do
           :tftp_master_path          => '/mnt/master_images',
           :instance_master_path      => '/mnt/ironic/master_images',
           :uefi_pxe_bootfile_name    => 'bootx64.efi',
+          :uefi_ipxe_bootfile_name    => 'ipxe.efi',
           :uefi_pxe_config_template  => 'foo-uefi',
           :ipxe_timeout              => '60',
-          :ipxe_enabled              => true,
           :pxe_bootfile_name         => 'bootx64',
           :boot_retry_timeout        => 600,
           :boot_retry_check_interval => 120,
@@ -110,7 +88,7 @@ describe 'ironic::drivers::pxe' do
       end
 
       it 'should replace default parameter with new value' do
-        is_expected.to contain_ironic_config('pxe/pxe_append_params').with_value(p[:pxe_append_params])
+        is_expected.to contain_ironic_config('pxe/kernel_append_params').with_value(p[:kernel_append_params])
         is_expected.to contain_ironic_config('pxe/pxe_config_template').with_value(p[:pxe_config_template])
         is_expected.to contain_ironic_config('pxe/tftp_server').with_value(p[:tftp_server])
         is_expected.to contain_ironic_config('pxe/tftp_root').with_value(p[:tftp_root])
@@ -119,8 +97,8 @@ describe 'ironic::drivers::pxe' do
         is_expected.to contain_ironic_config('pxe/instance_master_path').with_value(p[:instance_master_path])
         is_expected.to contain_ironic_config('pxe/uefi_pxe_bootfile_name').with_value(p[:uefi_pxe_bootfile_name])
         is_expected.to contain_ironic_config('pxe/uefi_pxe_config_template').with_value(p[:uefi_pxe_config_template])
+        is_expected.to contain_ironic_config('pxe/uefi_ipxe_bootfile_name').with_value(p[:uefi_ipxe_bootfile_name])
         is_expected.to contain_ironic_config('pxe/ipxe_timeout').with_value(p[:ipxe_timeout])
-        is_expected.to contain_ironic_config('pxe/ipxe_enabled').with_value(p[:ipxe_enabled])
         is_expected.to contain_ironic_config('pxe/pxe_bootfile_name').with_value(p[:pxe_bootfile_name])
         is_expected.to contain_ironic_config('pxe/boot_retry_timeout').with_value(p[:boot_retry_timeout])
         is_expected.to contain_ironic_config('pxe/boot_retry_check_interval').with_value(p[:boot_retry_check_interval])
