@@ -36,11 +36,13 @@ describe 'ironic::drivers::redfish' do
       is_expected.to contain_ironic_config('redfish/swift_object_expiry_timeout').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('redfish/kernel_append_params').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('redfish/file_permission').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('redfish/firmware_update_status_interval').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('redfish/firmware_update_fail_interval').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs sushy package' do
       is_expected.to contain_package('python-sushy').with(
-        :ensure => 'present',
+        :ensure => 'installed',
         :name   => platform_params[:sushy_package_name],
         :tag    => ['openstack', 'ironic-package'],
       )
@@ -49,15 +51,17 @@ describe 'ironic::drivers::redfish' do
     context 'when overriding parameters' do
       before do
         params.merge!(
-          :connection_attempts         => 10,
-          :connection_retry_interval   => 1,
-          :connection_cache_size       => 100,
-          :auth_type                   => 'auto',
-          :use_swift                   => true,
-          :swift_container             => 'ironic_redfish_container',
-          :swift_object_expiry_timeout => 900,
-          :kernel_append_params        => 'nofb nomodeset vga=normal',
-          :file_permission             => '0o644'
+          :connection_attempts             => 10,
+          :connection_retry_interval       => 1,
+          :connection_cache_size           => 100,
+          :auth_type                       => 'auto',
+          :use_swift                       => true,
+          :swift_container                 => 'ironic_redfish_container',
+          :swift_object_expiry_timeout     => 900,
+          :kernel_append_params            => 'nofb nomodeset vga=normal',
+          :file_permission                 => '0o644',
+          :firmware_update_status_interval => 60,
+          :firmware_update_fail_interval   => 60,
           )
       end
 
@@ -71,6 +75,8 @@ describe 'ironic::drivers::redfish' do
         is_expected.to contain_ironic_config('redfish/swift_object_expiry_timeout').with_value(900)
         is_expected.to contain_ironic_config('redfish/kernel_append_params').with_value('nofb nomodeset vga=normal')
         is_expected.to contain_ironic_config('redfish/file_permission').with_value('0o644')
+        is_expected.to contain_ironic_config('redfish/firmware_update_status_interval').with_value(60)
+        is_expected.to contain_ironic_config('redfish/firmware_update_fail_interval').with_value(60)
       end
     end
 
@@ -89,15 +95,7 @@ describe 'ironic::drivers::redfish' do
         when 'Debian'
           { :sushy_package_name => 'python3-sushy' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :sushy_package_name => 'python3-sushy' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :sushy_package_name => 'python3-sushy' }
-            else
-              { :sushy_package_name => 'python-sushy' }
-            end
-          end
+          { :sushy_package_name => 'python3-sushy' }
         end
       end
 
