@@ -215,7 +215,6 @@ describe 'ironic' do
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_ironic_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
@@ -243,7 +242,6 @@ describe 'ironic' do
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key') }
-      it { is_expected.to contain_ironic_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
@@ -281,19 +279,8 @@ describe 'ironic' do
           { :common_package_name => 'ironic-common',
             :lib_package_name    => 'python3-ironic-lib' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :common_package_name => 'openstack-ironic-common',
-              :lib_package_name    => 'python3-ironic-lib' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :common_package_name => 'openstack-ironic-common',
-                :lib_package_name    => 'python3-ironic-lib' }
-            else
-              { :common_package_name => 'openstack-ironic-common',
-                :lib_package_name    => 'python-ironic-lib' }
-            end
-          end
-
+          { :common_package_name => 'openstack-ironic-common',
+            :lib_package_name    => 'python3-ironic-lib' }
         end
       end
 
