@@ -4,11 +4,14 @@ describe 'ironic::inspector::db::sync' do
 
   shared_examples_for 'inspector-dbsync' do
 
+    it { is_expected.to contain_class('ironic::deps') }
+
     it 'runs ironic-inspectror-db_sync' do
       is_expected.to contain_exec('ironic-inspector-dbsync').with(
         :command     => 'ironic-inspector-dbsync --config-file /etc/ironic-inspector/inspector.conf upgrade',
         :path        => '/usr/bin',
         :user        => 'ironic-inspector',
+        :timeout     => 300,
         :refreshonly => 'true',
         :logoutput   => 'on_failure',
         :tag         => 'openstack-db',
