@@ -193,6 +193,9 @@ describe 'ironic::inspector' do
       is_expected.not_to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-option=tag:subnet3,option:router,2001:4888:a03:313a:c0:fe0:0:c000/
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-sequential-ip/
+      )
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
@@ -231,6 +234,7 @@ describe 'ironic::inspector' do
           :node_not_found_hook         => 'enroll',
           :discovery_default_driver    => 'pxe_ipmitool',
           :dnsmasq_ip_subnets          => [{'ip_range' => '192.168.0.100,192.168.0.120'}],
+          :dnsmasq_dhcp_sequential_ip  => false,
           :add_ports                   => 'all',
           :always_store_ramdisk_logs   => true,
           :port_physnet_cidr_map       => {'192.168.20.0/24' => 'physnet_a',
@@ -280,6 +284,9 @@ describe 'ironic::inspector' do
         is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
             /dhcp-option=tag:ipxe6,option6:bootfile-url,http:\/\/.*:3816\/inspector.ipxe/
         )
+        is_expected.not_to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-sequential-ip/
+        )
       end
       it 'should contain file /var/www/httpboot/inspector.ipxe' do
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with(
@@ -353,6 +360,38 @@ describe 'ironic::inspector' do
         )
       end
     end
+
+    context 'when enabling ppc64le support with http default transport' do
+      let :pre_condition do
+         "class { 'ironic::inspector::authtoken': password       => 'password', }
+          class { 'ironic::pxe':                  enable_ppc64le => true, }"
+      end
+
+      before do
+        params.merge!(
+          :enable_ppc64le        => true,
+          :pxe_transfer_protocol => 'http',
+        )
+      end
+
+      it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
+          is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-match=set:ppc64le,option:client-arch,14/)
+      end
+      it 'should contain file /tftpboot/ppc64le/default' do
+        is_expected.to contain_file('/tftpboot/ppc64le/default').with(
+          'owner'   => 'ironic-inspector',
+          'group'   => 'ironic-inspector',
+          'seltype' => 'tftpdir_t',
+          'ensure'  => 'present',
+          'require' => 'Anchor[ironic-inspector::config::begin]',
+          'content' => /default/,
+        )
+        is_expected.to contain_file('/tftpboot/ppc64le/default').with_content(
+            /initrd=agent.ramdisk ipa-inspection-callback-url=http:\/\/192.168.0.1:5050\/v1\/continue ipa-inspection-collectors=default/
+        )
+      end
+    end
   end
 
   on_supported_os({
