@@ -41,20 +41,24 @@ describe 'ironic::neutron' do
       is_expected.to contain_ironic_config('neutron/password').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('neutron/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_config('neutron/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_config('neutron/region_name').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/endpoint_override').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('neutron/dhcpv6_stateful_address_count').with_value('<SERVICE DEFAULT>')
     end
 
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-            :auth_type           => 'noauth',
-            :auth_url            => 'http://example.com',
-            :project_name        => 'project1',
-            :username            => 'admin',
-            :password            => 'pa$$w0rd',
-            :user_domain_name    => 'NonDefault',
-            :project_domain_name => 'NonDefault',
-            :endpoint_override   => 'http://example2.com',
+            :auth_type                     => 'noauth',
+            :auth_url                      => 'http://example.com',
+            :project_name                  => 'project1',
+            :username                      => 'admin',
+            :password                      => 'pa$$w0rd',
+            :user_domain_name              => 'NonDefault',
+            :project_domain_name           => 'NonDefault',
+            :region_name                   => 'regionTwo',
+            :endpoint_override             => 'http://example2.com',
+            :dhcpv6_stateful_address_count => 8,
         )
       end
 
@@ -66,7 +70,9 @@ describe 'ironic::neutron' do
         is_expected.to contain_ironic_config('neutron/password').with_value(p[:password]).with_secret(true)
         is_expected.to contain_ironic_config('neutron/user_domain_name').with_value(p[:user_domain_name])
         is_expected.to contain_ironic_config('neutron/project_domain_name').with_value(p[:project_domain_name])
+        is_expected.to contain_ironic_config('neutron/region_name').with_value(p[:region_name])
         is_expected.to contain_ironic_config('neutron/endpoint_override').with_value(p[:endpoint_override])
+        is_expected.to contain_ironic_config('neutron/dhcpv6_stateful_address_count').with_value(p[:dhcpv6_stateful_address_count])
       end
     end
 
